[PATCH 3/5] mci: mci-core: fix long lasting FIXMEs

Juergen Borleis jbe at pengutronix.de
Wed Sep 9 07:01:16 EDT 2020


Signed-off-by: Juergen Borleis <jbe at pengutronix.de>
---
 drivers/mci/mci-core.c | 22 +++++++++++++---------
 1 file changed, 13 insertions(+), 9 deletions(-)

diff --git a/drivers/mci/mci-core.c b/drivers/mci/mci-core.c
index a58dedc1cd..d93be6d33f 100644
--- a/drivers/mci/mci-core.c
+++ b/drivers/mci/mci-core.c
@@ -361,9 +361,9 @@ static int mmc_send_op_cond(struct mci *mci)
 }
 
 /**
  * FIXME
  * @param mci MCI instance
  * @param ext_csd Buffer for a 512 byte sized extended CSD
  * @return Transaction status (0 on success)
  *
  * Note: Only cards newer than Version 1.1 (Physical Layer Spec) support
@@ -379,19 +379,23 @@ int mci_send_ext_csd(struct mci *mci, char *ext_csd)
 
 	data.dest = ext_csd;
 	data.blocks = 1;
-	data.blocksize = 512;
+	data.blocksize = EXT_CSD_BLOCKSIZE;
 	data.flags = MMC_DATA_READ;
 
 	return mci_send_cmd(mci, &cmd, &data);
 }
 
 /**
- * FIXME
- * @param mci MCI instance
- * @param set FIXME
- * @param index FIXME
- * @param value FIXME
+ * Write a byte into the card's extended CSD configuration area
+ * @param[in] mci MCI instance
+ * @param[in] index Byte index in the extended CSD configuration area
+ * @param[in] value Byte to write at index into the extended CSD configuration area
  * @return Transaction status (0 on success)
+ *
+ * This sends a CMD6 (aka SWITCH) to the card and writes @b value at extended CSD @b index.
+ *
+ * @note It always writes a full byte, the alternatives 'bit set' and
+ *      'bit clear' aren't supported.
  */
 int mci_switch(struct mci *mci, unsigned index, unsigned value)
 {
@@ -361,9 +361,9 @@ static int mmc_send_op_cond(struct mci *mci)
 
 /**
- * FIXME
- * @param mci MCI instance
- * @param ext_csd Buffer for a 512 byte sized extended CSD
+ * Read-in the card's whole extended CSD configuration area
+ * @param[in] mci MCI instance
+ * @param[out] ext_csd Buffer for an #EXT_CSD_BLOCKSIZE byte sized extended CSD
  * @return Transaction status (0 on success)
  *
-- 
2.20.1




More information about the barebox mailing list